@@ -15,7 +15,7 @@
  * You should have received a copy of the  GNU General Public License along with
  * Touchégg. If not, see <http://www.gnu.org/licenses/>.
  *
- * @author José Expósito <jose.exposito89@gmail.com> (C) 2011
+ * @author José Expósito <jose.exposito89@gmail.com> (C) 2011 - 2012
  * @class  DragAndDrop
  */
 #ifndef DRAGANDDROP_H
@@ -25,34 +25,28 @@
 #include "src/touchegg/actions/implementation/Action.h"
 
 /**
- * @~spanish
- * Emula drag and drop (click y arrastrar).
- *
- * @~english
  * Emulates drag and drop (click and drag).
  */
-class DragAndDrop : public Action {
-
-private:
-
-    /**
-     * @~spanish
-     * Botón a emular.
-     *
-     * @~english
-     * Button to emulate.
-     */
-    int button;
+class DragAndDrop : public Action
+{
 
 public:
 
-    DragAndDrop(const QString& settings, Window window);
+    DragAndDrop(const QString &settings, Window window);
 
     void executeStart(const QHash<QString, QVariant>& attrs);
 
     void executeUpdate(const QHash<QString, QVariant>& attrs);
 
     void executeFinish(const QHash<QString, QVariant>& attrs);
+
+private:
+
+    /**
+     * Button to emulate.
+     */
+    int button;
+
 };
 
 #endif // DRAGANDDROP_H
